@@ -3,16 +3,16 @@
 use std::sync::Arc;
 
 use crate::comments::MultiThreadedComments;
+use crate::swc::ast::Program;
 use crate::swc::common::comments::SingleThreadedComments;
 use crate::swc::common::input::StringInput;
 use crate::swc::common::Spanned;
-use crate::swc::ecmascript::ast::Program;
-use crate::swc::ecmascript::parser::lexer::Lexer;
-use crate::swc::ecmascript::parser::token::TokenAndSpan;
-use crate::swc::ecmascript::parser::EsConfig;
-use crate::swc::ecmascript::parser::JscTarget;
-use crate::swc::ecmascript::parser::Syntax;
-use crate::swc::ecmascript::parser::TsConfig;
+use crate::swc::parser::lexer::Lexer;
+use crate::swc::parser::token::TokenAndSpan;
+use crate::swc::parser::EsConfig;
+use crate::swc::parser::JscTarget;
+use crate::swc::parser::Syntax;
+use crate::swc::parser::TsConfig;
 use crate::Diagnostic;
 use crate::MediaType;
 use crate::ParsedSource;
@@ -20,27 +20,33 @@ use crate::ParsedSourceTextInfo;
 
 static TARGET: JscTarget = JscTarget::Es2021;
 
-#[derive(Debug, Clone)]
 pub struct ParseParams {
   pub specifier: String,
   pub source: ParsedSourceTextInfo,
   pub media_type: MediaType,
   pub capture_tokens: bool,
+  pub maybe_syntax: Option<Syntax>,
 }
 
 pub fn parse_program(params: ParseParams) -> Result<ParsedSource, Diagnostic> {
-  parse(params, ParseMode::Program)
+  parse(params, ParseMode::Program, |p| p)
+}
+
+pub fn parse_program_with_post_process(
+  params: ParseParams,
+  post_process: impl FnOnce(Program) -> Program,
+) -> Result<ParsedSource, Diagnostic> {
+  parse(params, ParseMode::Program, post_process)
 }
 
 pub fn parse_module(params: ParseParams) -> Result<ParsedSource, Diagnostic> {
-  parse(params, ParseMode::Module)
+  parse(params, ParseMode::Module, |p| p)
 }
 
 pub fn parse_script(params: ParseParams) -> Result<ParsedSource, Diagnostic> {
-  parse(params, ParseMode::Script)
+  parse(params, ParseMode::Script, |p| p)
 }
 
-// currenly only have program and module because we never need only script
 enum ParseMode {
   Program,
   Module,
@@ -50,23 +56,25 @@ enum ParseMode {
 fn parse(
   params: ParseParams,
   parse_mode: ParseMode,
+  post_process: impl FnOnce(Program) -> Program,
 ) -> Result<ParsedSource, Diagnostic> {
   let source = params.source;
   let source_span = source.span();
   let specifier = params.specifier;
   let input =
     StringInput::new(source.text_str(), source_span.lo(), source_span.hi());
-  let (comments, program, tokens) = parse_string_input(
-    input,
-    &params.media_type,
-    params.capture_tokens,
-    parse_mode,
-  )
-  .map_err(|err| Diagnostic {
-    display_position: source.line_and_column_display(err.span().lo),
-    specifier: specifier.clone(),
-    message: err.into_kind().msg().to_string(),
-  })?;
+  let media_type = params.media_type;
+  let syntax = params
+    .maybe_syntax
+    .unwrap_or_else(|| get_syntax(media_type));
+  let (comments, program, tokens) =
+    parse_string_input(input, syntax, params.capture_tokens, parse_mode)
+      .map_err(|err| Diagnostic {
+        display_position: source.line_and_column_display(err.span().lo),
+        specifier: specifier.clone(),
+        message: err.into_kind().msg().to_string(),
+      })?;
+  let program = post_process(program);
 
   Ok(ParsedSource::new(
     specifier,
@@ -80,14 +88,13 @@ fn parse(
 
 fn parse_string_input(
   input: StringInput,
-  media_type: &MediaType,
+  syntax: Syntax,
   capture_tokens: bool,
   parse_mode: ParseMode,
 ) -> Result<
   (SingleThreadedComments, Program, Option<Vec<TokenAndSpan>>),
   swc_ecmascript::parser::error::Error,
 > {
-  let syntax = get_syntax(media_type);
   let comments = SingleThreadedComments::default();
   let lexer = Lexer::new(syntax, TARGET, input, Some(&comments));
 
@@ -114,7 +121,7 @@ fn parse_string_input(
   }
 }
 
-pub fn get_syntax(media_type: &MediaType) -> Syntax {
+pub fn get_syntax(media_type: MediaType) -> Syntax {
   match media_type {
     MediaType::JavaScript => Syntax::Es(get_es_config(false)),
     MediaType::Jsx => Syntax::Es(get_es_config(true)),
